@@ -3,12 +3,11 @@ use Mojo::Base -base;
 
 use Carp 'croak';
 use DBD::SQLite;
-use List::Util 'any';
 use Mojo::SQLite::Results;
 use Mojo::SQLite::Transaction;
 use Scalar::Util 'weaken';
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 
 has [qw(dbh sqlite)];
 
@@ -22,12 +21,13 @@ sub DESTROY {
   $sql->_enqueue($dbh);
 }
 
+my %behaviors = map { ($_ => 1) } qw(deferred immediate exclusive);
+
 sub begin {
   my $self = shift;
   if (@_) {
     my $behavior = shift;
-    croak qq{Invalid transaction behavior $behavior}
-      unless any { lc $behavior eq $_ } qw(deferred immediate exclusive);
+    croak qq{Invalid transaction behavior $behavior} unless exists $behaviors{lc $behavior};
     $self->dbh->do("begin $behavior transaction");
   } else {
     $self->dbh->begin_work;
@@ -53,7 +53,8 @@ sub query {
     local $@;
     eval {
       $sth = $self->dbh->prepare_cached($query, undef, 3);
-      $sth->execute(@_);
+      # If RaiseError has been disabled, we might not get a $sth
+      $sth->execute(@_) if defined $sth;
       1;
     } or $errored = 1;
     $error = $@ if $errored;
@@ -62,6 +63,9 @@ sub query {
   if ($errored) {
     die $error unless $cb;
     $error = $self->dbh->errstr;
+  } else {
+    # only possible with RaiseError disabled and error in prepare
+    return undef unless defined $sth;
   }
 
   my $results = Mojo::SQLite::Results->new(sth => $sth);
